@@ -5,7 +5,7 @@ from abc import ABC, abstractmethod
 from collections.abc import Iterable, Iterator
 from dataclasses import asdict, dataclass, field
 from pathlib import Path
-from typing import Annotated, Any, ClassVar, TypeVar
+from typing import Annotated, ClassVar, TypeVar
 
 from beartype.vale import Is
 from slugify import slugify
@@ -40,6 +40,7 @@ CasedSlugStr = Annotated[NeStr, Is[lambda s: is_cased_sluggy(s)]]
 TBuildableData = TypeVar("TBuildableData", bound="BuildableData")
 
 
+@dataclass(slots=True)
 class DataBuilder(BuildableBehavior[TBuildableData]):
     @classmethod
     def it_is_ready(cls, obj: TBuildableData) -> bool:
@@ -145,7 +146,7 @@ class BuildableDataClasses(BuildableData, IterableDataClasses[SomeDataclass]):
     def _generate_dataclasses(self) -> Iterator[SomeDataclass]:
         raise NotImplementedError
 
-    def _build_data(self) -> Any:
+    def _build_data(self) -> None:
         Path(self.data_dir).mkdir(parents=True, exist_ok=True)
         write_jsonl(
             self.jsonl_file,
