@@ -2,6 +2,8 @@ import dataclasses
 from dataclasses import dataclass
 from typing import Any, ClassVar, TypeVar
 
+from typing_extensions import Self
+
 from misc_python_utils.buildable_dataclasses.buildable import Buildable
 from misc_python_utils.dataclass_utils import UNDEFINED, Undefined
 
@@ -12,7 +14,7 @@ BASE_PATHES[
 ] = "."  # noqa: S105 -> this is a false-positive! pwd does not stand for "password" but the "current path"
 
 
-@dataclass
+@dataclass(slots=True)
 class PrefixSuffix(Buildable):
     prefix_key: str | Undefined = UNDEFINED
     suffix: str | Undefined = UNDEFINED
@@ -53,7 +55,7 @@ class PrefixSuffix(Buildable):
         self.prefix = BASE_PATHES[self.prefix_key]
         # assert len(self.prefix) > 0, f"base_path is empty!"
 
-    def from_str_same_prefix(self, path: str) -> "PrefixSuffix":
+    def from_str_same_prefix(self, path: str) -> Self:
         assert str(path).startswith(self.prefix)
         file_suffix = str(path).replace(f"{self.prefix}/", "")
         return PrefixSuffix(self.prefix_key, file_suffix)
